using System.Collections.Generic;
using System.Linq;
using UnityEditor;
using UnityEngine;

namespace MediaPipe {

static class TemplateBuilder
{
    const int VertexCount = FaceLandmark.FaceLandmarkDetector.VertexCount;

    [MenuItem("Assets/Create/MediaPipe/FaceLandmark/Create Template Meshes")]
    static void CreateTemplateMeshes()
    {
        ProjectWindowUtil.CreateAsset(BuildMesh(), "TemplateMesh.asset");
        ProjectWindowUtil.CreateAsset(BuildLineMesh(), "TemplateWire.asset");
        ProjectWindowUtil.CreateAsset(BuildPointMesh(), "TemplatePoints.asset");
    }

    static Mesh BuildMesh()
    {
        var mesh = new Mesh();
        mesh.SetVertices(new Vector3[VertexCount]);
        mesh.SetIndices(IndexList, MeshTopology.Triangles, 0);
        mesh.SetUVs(0, uvList);
        mesh.bounds = new Bounds(Vector3.zero, Vector3.one);
        return mesh;
    }

    static void TryAddIndexPair(List<(int, int)> pairs, int i1, int i2)
      => pairs.Add(i1 < i2 ? (i1, i2) : (i2, i1));

    static Mesh BuildLineMesh()
    {
        var pairs = new List<(int, int)>();

        for (var i = 0; i < IndexList.Length; i += 3)
        {
            TryAddIndexPair(pairs, IndexList[i + 0], IndexList[i + 1]);
            TryAddIndexPair(pairs, IndexList[i + 1], IndexList[i + 2]);
            TryAddIndexPair(pairs, IndexList[i + 2], IndexList[i + 0]);
        }

        var flatten =
          pairs.Distinct().SelectMany(p => new[]{ p.Item1, p.Item2 });

        var mesh = new Mesh();
        mesh.SetVertices(new Vector3[VertexCount]);
        mesh.SetIndices(flatten.ToArray(), MeshTopology.Lines, 0);
        mesh.bounds = new Bounds(Vector3.zero, Vector3.one);
        return mesh;
    }

    static Mesh BuildPointMesh()
    {
        var mesh = new Mesh();
        mesh.SetVertices(new Vector3[VertexCount]);
        mesh.SetIndices(new int[VertexCount], MeshTopology.Points, 0);
        mesh.bounds = new Bounds(Vector3.zero, Vector3.one);
        return mesh;
    }

    static int[] IndexList =
    {
        127,  34, 139,    11,   0,  37,   232, 231, 120,    72,  37,  39,
        128, 121,  47,   232, 121, 128,   104,  69,  67,   175, 171, 148,
        157, 154, 155,   118,  50, 101,    73,  39,  40,     9, 151, 108,
         48, 115, 131,   194, 204, 211,    74,  40, 185,    80,  42, 183,
         40,  92, 186,   230, 229, 118,   202, 212, 214,    83,  18,  17,
         76,  61, 146,   160,  29,  30,    56, 157, 173,   106, 204, 194,
        135, 214, 192,   203, 165,  98,    21,  71,  68,    51,  45,   4,
        144,  24,  23,    77, 146,  91,   205,  50, 187,   201, 200,  18,
         91, 106, 182,    90,  91, 181,    85,  84,  17,   206, 203,  36,
        148, 171, 140,    92,  40,  39,   193, 189, 244,   159, 158,  28,
        247, 246, 161,   236,   3, 196,    54,  68, 104,   193, 168,   8,
        117, 228,  31,   189, 193,  55,    98,  97,  99,   126,  47, 100,
        166,  79, 218,   155, 154,  26,   209,  49, 131,   135, 136, 150,
         47, 126, 217,   223,  52,  53,    45,  51, 134,   211, 170, 140,
         67,  69, 108,    43, 106,  91,   230, 119, 120,   226, 130, 247,
         63,  53,  52,   238,  20, 242,    46,  70, 156,    78,  62,  96,
         46,  53,  63,   143,  34, 227,   173, 155, 133,   123, 117, 111,
         44, 125,  19,   236, 134,  51,   216, 206, 205,   154, 153,  22,
         39,  37, 167,   200, 201, 208,    36, 142, 100,    57, 212, 202,
         20,  60,  99,    28, 158, 157,    35, 226, 113,   160, 159,  27,
        204, 202, 210,   113, 225,  46,    43, 202, 204,    62,  76,  77,
        137, 123, 116,    41,  38,  72,   203, 129, 142,    64,  98, 240,
         49, 102,  64,    41,  73,  74,   212, 216, 207,    42,  74, 184,
        169, 170, 211,   170, 149, 176,   105,  66,  69,   122,   6, 168,
        123, 147, 187,    96,  77,  90,    65,  55, 107,    89,  90, 180,
        101, 100, 120,    63, 105, 104,    93, 137, 227,    15,  86,  85,
        129, 102,  49,    14,  87,  86,    55,   8,   9,   100,  47, 121,
        145,  23,  22,    88,  89, 179,     6, 122, 196,    88,  95,  96,
        138, 172, 136,   215,  58, 172,   115,  48, 219,    42,  80,  81,
        195,   3,  51,    43, 146,  61,   171, 175, 199,    81,  82,  38,
         53,  46, 225,   144, 163, 110,   246,  33,   7,    52,  65,  66,
        229, 228, 117,    34, 127, 234,   107, 108,  69,   109, 108, 151,
         48,  64, 235,    62,  78, 191,   129, 209, 126,   111,  35, 143,
        163, 161, 246,   117, 123,  50,   222,  65,  52,    19, 125, 141,
        221,  55,  65,     3, 195, 197,    25,   7,  33,   220, 237,  44,
         70,  71, 139,   122, 193, 245,   247, 130,  33,    71,  21, 162,
        153, 158, 159,   170, 169, 150,   188, 174, 196,   216, 186,  92,
        144, 160, 161,     2,  97, 167,   141, 125, 241,   164, 167,  37,
         72,  38,  12,   145, 159, 160,    38,  82,  13,    63,  68,  71,
        226,  35, 111,   158, 153, 154,   101,  50, 205,   206,  92, 165,
        209, 198, 217,   165, 167,  97,   220, 115, 218,   133, 112, 243,
        239, 238, 241,   214, 135, 169,   190, 173, 133,   171, 208,  32,
        125,  44, 237,    86,  87, 178,    85,  86, 179,    84,  85, 180,
         83,  84, 181,   201,  83, 182,   137,  93, 132,    76,  62, 183,
         61,  76, 184,    57,  61, 185,   212,  57, 186,   214, 207, 187,
         34, 143, 156,    79, 239, 237,   123, 137, 177,    44,   1,   4,
        201, 194,  32,    64, 102, 129,   213, 215, 138,    59, 166, 219,
        242,  99,  97,     2,  94, 141,    75,  59, 235,    24, 110, 228,
         25, 130, 226,    23,  24, 229,    22,  23, 230,    26,  22, 231,
        112,  26, 232,   189, 190, 243,   221,  56, 190,    28,  56, 221,
         27,  28, 222,    29,  27, 223,    30,  29, 224,   247,  30, 225,
        238,  79,  20,   166,  59,  75,    60,  75, 240,   147, 177, 215,
         20,  79, 166,   187, 147, 213,   112, 233, 244,   233, 128, 245,
        128, 114, 188,   114, 217, 174,   131, 115, 220,   217, 198, 236,
        198, 131, 134,   177, 132,  58,   143,  35, 124,   110, 163,   7,
        228, 110,  25,   356, 389, 368,    11, 302, 267,   452, 350, 349,
        302, 303, 269,   357, 343, 277,   452, 453, 357,   333, 332, 297,
        175, 152, 377,   384, 398, 382,   347, 348, 330,   303, 304, 270,
          9, 336, 337,   278, 279, 360,   418, 262, 431,   304, 408, 409,
        310, 415, 407,   270, 409, 410,   450, 348, 347,   422, 430, 434,
        313, 314,  17,   306, 307, 375,   387, 388, 260,   286, 414, 398,
        335, 406, 418,   364, 367, 416,   423, 358, 327,   251, 284, 298,
        281,   5,   4,   373, 374, 253,   307, 320, 321,   425, 427, 411,
        421, 313,  18,   321, 405, 406,   320, 404, 405,   315,  16,  17,
        426, 425, 266,   377, 400, 369,   322, 391, 269,   417, 465, 464,
        386, 257, 258,   466, 260, 388,   456, 399, 419,   284, 332, 333,
        417, 285,   8,   346, 340, 261,   413, 441, 285,   327, 460, 328,
        355, 371, 329,   392, 439, 438,   382, 341, 256,   429, 420, 360,
        364, 394, 379,   277, 343, 437,   443, 444, 283,   275, 440, 363,
        431, 262, 369,   297, 338, 337,   273, 375, 321,   450, 451, 349,
        446, 342, 467,   293, 334, 282,   458, 461, 462,   276, 353, 383,
        308, 324, 325,   276, 300, 293,   372, 345, 447,   382, 398, 362,
        352, 345, 340,   274,   1,  19,   456, 248, 281,   436, 427, 425,
        381, 256, 252,   269, 391, 393,   200, 199, 428,   266, 330, 329,
        287, 273, 422,   250, 462, 328,   258, 286, 384,   265, 353, 342,
        387, 259, 257,   424, 431, 430,   342, 353, 276,   273, 335, 424,
        292, 325, 307,   366, 447, 345,   271, 303, 302,   423, 266, 371,
        294, 455, 460,   279, 278, 294,   271, 272, 304,   432, 434, 427,
        272, 407, 408,   394, 430, 431,   395, 369, 400,   334, 333, 299,
        351, 417, 168,   352, 280, 411,   325, 319, 320,   295, 296, 336,
        319, 403, 404,   330, 348, 349,   293, 298, 333,   323, 454, 447,
         15,  16, 315,   358, 429, 279,    14,  15, 316,   285, 336,   9,
        329, 349, 350,   374, 380, 252,   318, 402, 403,     6, 197, 419,
        318, 319, 325,   367, 364, 365,   435, 367, 397,   344, 438, 439,
        272, 271, 311,   195,   5, 281,   273, 287, 291,   396, 428, 199,
        311, 271, 268,   283, 444, 445,   373, 254, 339,   263, 466, 249,
        282, 334, 296,   449, 347, 346,   264, 447, 454,   336, 296, 299,
        338,  10, 151,   278, 439, 455,   292, 407, 415,   358, 371, 355,
        340, 345, 372,   390, 249, 466,   346, 347, 280,   442, 443, 282,
         19,  94, 370,   441, 442, 295,   248, 419, 197,   263, 255, 359,
        440, 275, 274,   300, 383, 368,   351, 412, 465,   263, 467, 466,
        301, 368, 389,   380, 374, 386,   395, 378, 379,   412, 351, 419,
        436, 426, 322,   373, 390, 388,     2, 164, 393,   370, 462, 461,
        164,   0, 267,   302,  11,  12,   374, 373, 387,   268,  12,  13,
        293, 300, 301,   446, 261, 340,   385, 384, 381,   330, 266, 425,
        426, 423, 391,   429, 355, 437,   391, 327, 326,   440, 457, 438,
        341, 382, 362,   459, 457, 461,   434, 430, 394,   414, 463, 362,
        396, 369, 262,   354, 461, 457,   316, 403, 402,   315, 404, 403,
        314, 405, 404,   313, 406, 405,   421, 418, 406,   366, 401, 361,
        306, 408, 407,   291, 409, 408,   287, 410, 409,   432, 436, 410,
        434, 416, 411,   264, 368, 383,   309, 438, 457,   352, 376, 401,
        274, 275,   4,   421, 428, 262,   294, 327, 358,   433, 416, 367,
        289, 455, 439,   462, 370, 326,     2, 326, 370,   305, 460, 455,
        254, 449, 448,   255, 261, 446,   253, 450, 449,   252, 451, 450,
        256, 452, 451,   341, 453, 452,   413, 464, 463,   441, 413, 414,
        258, 442, 441,   257, 443, 442,   259, 444, 443,   260, 445, 444,
        467, 342, 445,   459, 458, 250,   289, 392, 290,   290, 328, 460,
        376, 433, 435,   250, 290, 392,   411, 416, 433,   341, 463, 464,
        453, 464, 465,   357, 465, 412,   343, 412, 399,   360, 363, 440,
        437, 399, 456,   420, 456, 363,   401, 435, 288,   372, 383, 353,
        339, 255, 249,   448, 261, 255,   133, 243, 190,   133, 155, 112,
         33, 246, 247,    33, 130,  25,   398, 384, 286,   362, 398, 414,
        362, 463, 341,   263, 359, 467,   263, 249, 255,   466, 467, 260,
         75,  60, 166,   238, 239,  79,   162, 127, 139,    72,  11,  37,
        121, 232, 120,    73,  72,  39,   114, 128,  47,   233, 232, 128,
        103, 104,  67,   152, 175, 148,   173, 157, 155,   119, 118, 101,
         74,  73,  40,   107,   9, 108,    49,  48, 131,    32, 194, 211,
        184,  74, 185,   191,  80, 183,   185,  40, 186,   119, 230, 118,
        210, 202, 214,    84,  83,  17,    77,  76, 146,   161, 160,  30,
        190,  56, 173,   182, 106, 194,   138, 135, 192,   129, 203,  98,
         54,  21,  68,     5,  51,   4,   145, 144,  23,    90,  77,  91,
        207, 205, 187,    83, 201,  18,   181,  91, 182,   180,  90, 181,
         16,  85,  17,   205, 206,  36,   176, 148, 140,   165,  92,  39,
        245, 193, 244,    27, 159,  28,    30, 247, 161,   174, 236, 196,
        103,  54, 104,    55, 193,   8,   111, 117,  31,   221, 189,  55,
        240,  98,  99,   142, 126, 100,   219, 166, 218,   112, 155,  26,
        198, 209, 131,   169, 135, 150,   114,  47, 217,   224, 223,  53,
        220,  45, 134,    32, 211, 140,   109,  67, 108,   146,  43,  91,
        231, 230, 120,   113, 226, 247,   105,  63,  52,   241, 238, 242,
        124,  46, 156,    95,  78,  96,    70,  46,  63,   116, 143, 227,
        116, 123, 111,     1,  44,  19,     3, 236,  51,   207, 216, 205,
         26, 154,  22,   165,  39, 167,   199, 200, 208,   101,  36, 100,
         43,  57, 202,   242,  20,  99,    56,  28, 157,   124,  35, 113,
         29, 160,  27,   211, 204, 210,   124, 113,  46,   106,  43, 204,
         96,  62,  77,   227, 137, 116,    73,  41,  72,    36, 203, 142,
        235,  64, 240,    48,  49,  64,    42,  41,  74,   214, 212, 207,
        183,  42, 184,   210, 169, 211,   140, 170, 176,   104, 105,  69,
        193, 122, 168,    50, 123, 187,    89,  96,  90,    66,  65, 107,
        179,  89, 180,   119, 101, 120,    68,  63, 104,   234,  93, 227,
         16,  15,  85,   209, 129,  49,    15,  14,  86,   107,  55,   9,
        120, 100, 121,   153, 145,  22,   178,  88, 179,   197,   6, 196,
         89,  88,  96,   135, 138, 136,   138, 215, 172,   218, 115, 219,
         41,  42,  81,     5, 195,  51,    57,  43,  61,   208, 171, 199,
         41,  81,  38,   224,  53, 225,    24, 144, 110,   105,  52,  66,
        118, 229, 117,   227,  34, 234,    66, 107,  69,    10, 109, 151,
        219,  48, 235,   183,  62, 191,   142, 129, 126,   116, 111, 143,
          7, 163, 246,   118, 117,  50,   223, 222,  52,    94,  19, 141,
        222, 221,  65,   196,   3, 197,    45, 220,  44,   156,  70, 139,
        188, 122, 245,   139,  71, 162,   145, 153, 159,   149, 170, 150,
        122, 188, 196,   206, 216,  92,   163, 144, 161,   164,   2, 167,
        242, 141, 241,     0, 164,  37,    11,  72,  12,   144, 145, 160,
         12,  38,  13,    70,  63,  71,    31, 226, 111,   157, 158, 154,
         36, 101, 205,   203, 206, 165,   126, 209, 217,    98, 165,  97,
        237, 220, 218,   237, 239, 241,   210, 214, 169,   140, 171,  32,
        241, 125, 237,   179,  86, 178,   180,  85, 179,   181,  84, 180,
        182,  83, 181,   194, 201, 182,   177, 137, 132,   184,  76, 183,
        185,  61, 184,   186,  57, 185,   216, 212, 186,   192, 214, 187,
        139,  34, 156,   218,  79, 237,   147, 123, 177,    45,  44,   4,
        208, 201,  32,    98,  64, 129,   192, 213, 138,   235,  59, 219,
        141, 242,  97,    97,   2, 141,   240,  75, 235,   229,  24, 228,
         31,  25, 226,   230,  23, 229,   231,  22, 230,   232,  26, 231,
        233, 112, 232,   244, 189, 243,   189, 221, 190,   222,  28, 221,
        223,  27, 222,   224,  29, 223,   225,  30, 224,   113, 247, 225,
         99,  60, 240,   213, 147, 215,    60,  20, 166,   192, 187, 213,
        243, 112, 244,   244, 233, 245,   245, 128, 188,   188, 114, 174,
        134, 131, 220,   174, 217, 236,   236, 198, 134,   215, 177,  58,
        156, 143, 124,    25, 110,   7,    31, 228,  25,   264, 356, 368,
          0,  11, 267,   451, 452, 349,   267, 302, 269,   350, 357, 277,
        350, 452, 357,   299, 333, 297,   396, 175, 377,   381, 384, 382,
        280, 347, 330,   269, 303, 270,   151,   9, 337,   344, 278, 360,
        424, 418, 431,   270, 304, 409,   272, 310, 407,   322, 270, 410,
        449, 450, 347,   432, 422, 434,    18, 313,  17,   291, 306, 375,
        259, 387, 260,   424, 335, 418,   434, 364, 416,   391, 423, 327,
        301, 251, 298,   275, 281,   4,   254, 373, 253,   375, 307, 321,
        280, 425, 411,   200, 421,  18,   335, 321, 406,   321, 320, 405,
        314, 315,  17,   423, 426, 266,   396, 377, 369,   270, 322, 269,
        413, 417, 464,   385, 386, 258,   248, 456, 419,   298, 284, 333,
        168, 417,   8,   448, 346, 261,   417, 413, 285,   326, 327, 328,
        277, 355, 329,   309, 392, 438,   381, 382, 256,   279, 429, 360,
        365, 364, 379,   355, 277, 437,   282, 443, 283,   281, 275, 363,
        395, 431, 369,   299, 297, 337,   335, 273, 321,   348, 450, 349,
        359, 446, 467,   283, 293, 282,   250, 458, 462,   300, 276, 383,
        292, 308, 325,   283, 276, 293,   264, 372, 447,   346, 352, 340,
        354, 274,  19,   363, 456, 281,   426, 436, 425,   380, 381, 252,
        267, 269, 393,   421, 200, 428,   371, 266, 329,   432, 287, 422,
        290, 250, 328,   385, 258, 384,   446, 265, 342,   386, 387, 257,
        422, 424, 430,   445, 342, 276,   422, 273, 424,   306, 292, 307,
        352, 366, 345,   268, 271, 302,   358, 423, 371,   327, 294, 460,
        331, 279, 294,   303, 271, 304,   436, 432, 427,   304, 272, 408,
        395, 394, 431,   378, 395, 400,   296, 334, 299,     6, 351, 168,
        376, 352, 411,   307, 325, 320,   285, 295, 336,   320, 319, 404,
        329, 330, 349,   334, 293, 333,   366, 323, 447,   316,  15, 315,
        331, 358, 279,   317,  14, 316,     8, 285,   9,   277, 329, 350,
        253, 374, 252,   319, 318, 403,   351,   6, 419,   324, 318, 325,
        397, 367, 365,   288, 435, 397,   278, 344, 439,   310, 272, 311,
        248, 195, 281,   375, 273, 291,   175, 396, 199,   312, 311, 268,
        276, 283, 445,   390, 373, 339,   295, 282, 296,   448, 449, 346,
        356, 264, 454,   337, 336, 299,   337, 338, 151,   294, 278, 455,
        308, 292, 415,   429, 358, 355,   265, 340, 372,   388, 390, 466,
        352, 346, 280,   295, 442, 282,   354,  19, 370,   285, 441, 295,
        195, 248, 197,   457, 440, 274,   301, 300, 368,   417, 351, 465,
        251, 301, 389,   385, 380, 386,   394, 395, 379,   399, 412, 419,
        410, 436, 322,   387, 373, 388,   326,   2, 393,   354, 370, 461,
        393, 164, 267,   268, 302,  12,   386, 374, 387,   312, 268,  13,
        298, 293, 301,   265, 446, 340,   380, 385, 381,   280, 330, 425,
        322, 426, 391,   420, 429, 437,   393, 391, 326,   344, 440, 438,
        458, 459, 461,   364, 434, 394,   428, 396, 262,   274, 354, 457,
        317, 316, 402,   316, 315, 403,   315, 314, 404,   314, 313, 405,
        313, 421, 406,   323, 366, 361,   292, 306, 407,   306, 291, 408,
        291, 287, 409,   287, 432, 410,   427, 434, 411,   372, 264, 383,
        459, 309, 457,   366, 352, 401,     1, 274,   4,   418, 421, 262,
        331, 294, 358,   435, 433, 367,   392, 289, 439,   328, 462, 326,
         94,   2, 370,   289, 305, 455,   339, 254, 448,   359, 255, 446,
        254, 253, 449,   253, 252, 450,   252, 256, 451,   256, 341, 452,
        414, 413, 463,   286, 441, 414,   286, 258, 441,   258, 257, 442,
        257, 259, 443,   259, 260, 444,   260, 467, 445,   309, 459, 250,
        305, 289, 290,   305, 290, 460,   401, 376, 435,   309, 250, 392,
        376, 411, 433,   453, 341, 464,   357, 453, 465,   343, 357, 412,
        437, 343, 399,   344, 360, 440,   420, 437, 456,   360, 420, 363,
        361, 401, 288,   265, 372, 353,   390, 339, 249,   339, 448, 255
    };

    static Vector2[] uvList =
    {
        new Vector2(0.4999769926f, 0.3474659920f),
        new Vector2(0.5000259876f, 0.4525129795f),
        new Vector2(0.4999740124f, 0.3976280093f),
        new Vector2(0.4821130037f, 0.5280209780f),
        new Vector2(0.5001509786f, 0.4728440046f),
        new Vector2(0.4999099970f, 0.5017470121f),
        new Vector2(0.4995230138f, 0.5989379883f),
        new Vector2(0.2897120118f, 0.6192359924f),
        new Vector2(0.4999549985f, 0.6876019835f),
        new Vector2(0.4999870062f, 0.7300810218f),
        new Vector2(0.5000230074f, 0.8929499984f),
        new Vector2(0.5000230074f, 0.3337659836f),
        new Vector2(0.5000159740f, 0.3207759857f),
        new Vector2(0.5000230074f, 0.3076519966f),
        new Vector2(0.4999769926f, 0.3047220111f),
        new Vector2(0.4999769926f, 0.2940660119f),
        new Vector2(0.4999769926f, 0.2806149721f),
        new Vector2(0.4999769926f, 0.2629809976f),
        new Vector2(0.4999679923f, 0.2186290026f),
        new Vector2(0.4998160005f, 0.4370189905f),
        new Vector2(0.4737730026f, 0.4260900021f),
        new Vector2(0.1049069986f, 0.7458590269f),
        new Vector2(0.3659299910f, 0.5904240012f),
        new Vector2(0.3387579918f, 0.5869749784f),
        new Vector2(0.3111200035f, 0.5905399919f),
        new Vector2(0.2746579945f, 0.6108689904f),
        new Vector2(0.3933619857f, 0.5962939858f),
        new Vector2(0.3452340066f, 0.6559889913f),
        new Vector2(0.3700940013f, 0.6539239883f),
        new Vector2(0.3193219900f, 0.6527349949f),
        new Vector2(0.2979030013f, 0.6464089751f),
        new Vector2(0.2477920055f, 0.5891900063f),
        new Vector2(0.3968890011f, 0.1572449803f),
        new Vector2(0.2800979912f, 0.6244000196f),
        new Vector2(0.1063100025f, 0.6000440121f),
        new Vector2(0.2099249959f, 0.6086469889f),
        new Vector2(0.3558079898f, 0.4655939937f),
        new Vector2(0.4717510045f, 0.3495960236f),
        new Vector2(0.4741550088f, 0.3198080063f),
        new Vector2(0.4397850037f, 0.3427709937f),
        new Vector2(0.4146170020f, 0.3334590197f),
        new Vector2(0.4503740072f, 0.3191390038f),
        new Vector2(0.4287709892f, 0.3173090219f),
        new Vector2(0.3749710023f, 0.2721949816f),
        new Vector2(0.4867169857f, 0.4523710012f),
        new Vector2(0.4853009880f, 0.4726049900f),
        new Vector2(0.2577649951f, 0.6855099797f),
        new Vector2(0.4012230039f, 0.5448279977f),
        new Vector2(0.4298189878f, 0.4513850212f),
        new Vector2(0.4213519990f, 0.4662590027f),
        new Vector2(0.2768959999f, 0.4679430127f),
        new Vector2(0.4833700061f, 0.5004130006f),
        new Vector2(0.3372119963f, 0.7171170115f),
        new Vector2(0.2963919938f, 0.7067570090f),
        new Vector2(0.1692949980f, 0.8061860204f),
        new Vector2(0.4475800097f, 0.6973900199f),
        new Vector2(0.3923900127f, 0.6461120248f),
        new Vector2(0.3544900119f, 0.3032159805f),
        new Vector2(0.0673049986f, 0.2698949575f),
        new Vector2(0.4427390099f, 0.4271739721f),
        new Vector2(0.4570980072f, 0.4152079821f),
        new Vector2(0.3819740117f, 0.3052890301f),
        new Vector2(0.3923889995f, 0.3057969809f),
        new Vector2(0.2770760059f, 0.7280679941f),
        new Vector2(0.4225519896f, 0.4367669821f),
        new Vector2(0.3859190047f, 0.7186359763f),
        new Vector2(0.3831030130f, 0.7441599965f),
        new Vector2(0.3314310014f, 0.8802859783f),
        new Vector2(0.2299239933f, 0.7679970264f),
        new Vector2(0.3645009995f, 0.8108860254f),
        new Vector2(0.2296220064f, 0.7004590034f),
        new Vector2(0.1732870042f, 0.7212520242f),
        new Vector2(0.4728789926f, 0.3338019848f),
        new Vector2(0.4468280077f, 0.3314729929f),
        new Vector2(0.4227620065f, 0.3261100054f),
        new Vector2(0.4453079998f, 0.4199340343f),
        new Vector2(0.3881030083f, 0.3060389757f),
        new Vector2(0.4030390084f, 0.2934600115f),
        new Vector2(0.4036290050f, 0.3060469627f),
        new Vector2(0.4600419998f, 0.4428609610f),
        new Vector2(0.4311580062f, 0.3076339960f),
        new Vector2(0.4521819949f, 0.3076339960f),
        new Vector2(0.4753870070f, 0.3076339960f),
        new Vector2(0.4658280015f, 0.2208099961f),
        new Vector2(0.4723289907f, 0.2637740374f),
        new Vector2(0.4730870128f, 0.2821429968f),
        new Vector2(0.4731220007f, 0.2953740358f),
        new Vector2(0.4730330110f, 0.3047220111f),
        new Vector2(0.4279420078f, 0.3047220111f),
        new Vector2(0.4264790118f, 0.2964600325f),
        new Vector2(0.4231620133f, 0.2881540060f),
        new Vector2(0.4183090031f, 0.2799370289f),
        new Vector2(0.3900949955f, 0.3604270220f),
        new Vector2(0.0139539996f, 0.4399659634f),
        new Vector2(0.4999139905f, 0.4198529720f),
        new Vector2(0.4131999910f, 0.3046000004f),
        new Vector2(0.4096260071f, 0.2981770039f),
        new Vector2(0.4680800140f, 0.3984650373f),
        new Vector2(0.4227289855f, 0.4140149951f),
        new Vector2(0.4630799890f, 0.4062160254f),
        new Vector2(0.3721199930f, 0.5265859962f),
        new Vector2(0.3345620036f, 0.5039269924f),
        new Vector2(0.4116710126f, 0.4530349970f),
        new Vector2(0.2421759963f, 0.8523240089f),
        new Vector2(0.2907769978f, 0.7985540032f),
        new Vector2(0.3273380101f, 0.7434729934f),
        new Vector2(0.3995099962f, 0.2510789633f),
        new Vector2(0.4417279959f, 0.7383239865f),
        new Vector2(0.4297649860f, 0.8121659756f),
        new Vector2(0.4121980071f, 0.8910989761f),
        new Vector2(0.2889550030f, 0.6010479927f),
        new Vector2(0.2189369947f, 0.5645890236f),
        new Vector2(0.4127820134f, 0.6010299921f),
        new Vector2(0.2571350038f, 0.6445599794f),
        new Vector2(0.4276849926f, 0.5620390177f),
        new Vector2(0.4483399987f, 0.4630639553f),
        new Vector2(0.1785600036f, 0.5424460173f),
        new Vector2(0.2473080009f, 0.5428060293f),
        new Vector2(0.2862670124f, 0.5323250294f),
        new Vector2(0.3328279853f, 0.5392879844f),
        new Vector2(0.3687559962f, 0.5527930260f),
        new Vector2(0.3989639878f, 0.5673450232f),
        new Vector2(0.4764100015f, 0.5941939950f),
        new Vector2(0.1892410070f, 0.4760760069f),
        new Vector2(0.2289620042f, 0.6510490179f),
        new Vector2(0.4907259941f, 0.4375990033f),
        new Vector2(0.4046700001f, 0.5148670077f),
        new Vector2(0.0194690004f, 0.5984359980f),
        new Vector2(0.4262430072f, 0.5795689821f),
        new Vector2(0.3969930112f, 0.4512029886f),
        new Vector2(0.2664699852f, 0.6230229735f),
        new Vector2(0.4391210079f, 0.4810420275f),
        new Vector2(0.0323139988f, 0.3556430340f),
        new Vector2(0.4190540016f, 0.6128450036f),
        new Vector2(0.4627830088f, 0.4942530394f),
        new Vector2(0.2389789969f, 0.2202550173f),
        new Vector2(0.1982209980f, 0.1680619717f),
        new Vector2(0.1075500026f, 0.4592449665f),
        new Vector2(0.1836100072f, 0.2597429752f),
        new Vector2(0.1344099939f, 0.6663169861f),
        new Vector2(0.3857640028f, 0.1168460250f),
        new Vector2(0.4909670055f, 0.4206219912f),
        new Vector2(0.3823849857f, 0.4914270043f),
        new Vector2(0.1743990034f, 0.6023290157f),
        new Vector2(0.3187850118f, 0.6037650108f),
        new Vector2(0.3433640003f, 0.5994030237f),
        new Vector2(0.3961000144f, 0.2897830009f),
        new Vector2(0.1878850013f, 0.4114620090f),
        new Vector2(0.4309870005f, 0.0559350252f),
        new Vector2(0.3189930022f, 0.1017149687f),
        new Vector2(0.2662479877f, 0.1302989721f),
        new Vector2(0.5000230074f, 0.8094239831f),
        new Vector2(0.4999769926f, 0.0455470085f),
        new Vector2(0.3661699891f, 0.6011779904f),
        new Vector2(0.3932070136f, 0.6044629812f),
        new Vector2(0.4103730023f, 0.6089199781f),
        new Vector2(0.1949930042f, 0.6578980088f),
        new Vector2(0.3886649907f, 0.6377159953f),
        new Vector2(0.3659619987f, 0.6440290213f),
        new Vector2(0.3433640003f, 0.6446430087f),
        new Vector2(0.3187850118f, 0.6416599751f),
        new Vector2(0.3014149964f, 0.6368439794f),
        new Vector2(0.0581329986f, 0.6809239984f),
        new Vector2(0.3014149964f, 0.6125509739f),
        new Vector2(0.4999879897f, 0.3815659881f),
        new Vector2(0.4158380032f, 0.3758040071f),
        new Vector2(0.4456819892f, 0.4339230061f),
        new Vector2(0.4658440053f, 0.3793590069f),
        new Vector2(0.4999229908f, 0.6484760046f),
        new Vector2(0.2887189984f, 0.1800540090f),
        new Vector2(0.3352789879f, 0.1471800208f),
        new Vector2(0.4405120015f, 0.0975810289f),
        new Vector2(0.1282940060f, 0.2080590129f),
        new Vector2(0.4087719917f, 0.6261060238f),
        new Vector2(0.4556069970f, 0.5481989980f),
        new Vector2(0.4998770058f, 0.0910099745f),
        new Vector2(0.3754369915f, 0.0758079886f),
        new Vector2(0.1142100021f, 0.3849779963f),
        new Vector2(0.4486620128f, 0.3047220111f),
        new Vector2(0.4480200112f, 0.2953679562f),
        new Vector2(0.4471119940f, 0.2841919661f),
        new Vector2(0.4448319972f, 0.2692059875f),
        new Vector2(0.4300119877f, 0.2331910133f),
        new Vector2(0.4067870080f, 0.3143270016f),
        new Vector2(0.4007380009f, 0.3189309835f),
        new Vector2(0.3923999965f, 0.3222969770f),
        new Vector2(0.3678559959f, 0.3360810280f),
        new Vector2(0.2479230016f, 0.3986669779f),
        new Vector2(0.4527699947f, 0.5791500211f),
        new Vector2(0.4363920093f, 0.6401129961f),
        new Vector2(0.4161640108f, 0.6312860250f),
        new Vector2(0.4133859873f, 0.3076339960f),
        new Vector2(0.2280180007f, 0.3164280057f),
        new Vector2(0.4682680070f, 0.6473289728f),
        new Vector2(0.4113619924f, 0.1956729889f),
        new Vector2(0.4999890029f, 0.5301749706f),
        new Vector2(0.4791539907f, 0.5573459864f),
        new Vector2(0.4999740124f, 0.5603629947f),
        new Vector2(0.4321120083f, 0.5064110160f),
        new Vector2(0.4998860061f, 0.1330829859f),
        new Vector2(0.4999130070f, 0.1782709956f),
        new Vector2(0.4565489888f, 0.1807990074f),
        new Vector2(0.3445490003f, 0.2545610070f),
        new Vector2(0.3789089918f, 0.4259899855f),
        new Vector2(0.3742929995f, 0.2198150158f),
        new Vector2(0.3196879923f, 0.4292620420f),
        new Vector2(0.3571549952f, 0.3957300186f),
        new Vector2(0.2952840030f, 0.3784190416f),
        new Vector2(0.4477500021f, 0.1375229955f),
        new Vector2(0.4109860063f, 0.4912769794f),
        new Vector2(0.3139509857f, 0.2246919870f),
        new Vector2(0.3541280031f, 0.1874470115f),
        new Vector2(0.3245480061f, 0.2960070372f),
        new Vector2(0.1890960038f, 0.3537000418f),
        new Vector2(0.2797769904f, 0.2853419781f),
        new Vector2(0.1338230073f, 0.3172990084f),
        new Vector2(0.3367680013f, 0.3552669883f),
        new Vector2(0.4298839867f, 0.5334780216f),
        new Vector2(0.4555279911f, 0.4513770342f),
        new Vector2(0.4371140003f, 0.4411039948f),
        new Vector2(0.4672879875f, 0.4700750113f),
        new Vector2(0.4147120118f, 0.6647800207f),
        new Vector2(0.3770459890f, 0.6772220135f),
        new Vector2(0.3441079855f, 0.6798490286f),
        new Vector2(0.3128759861f, 0.6776679754f),
        new Vector2(0.2835260034f, 0.6668099761f),
        new Vector2(0.2412459999f, 0.6172140241f),
        new Vector2(0.1029860005f, 0.5312370062f),
        new Vector2(0.2676120102f, 0.5754399896f),
        new Vector2(0.2978790104f, 0.5668240190f),
        new Vector2(0.3334339857f, 0.5661219954f),
        new Vector2(0.3664270043f, 0.5738840103f),
        new Vector2(0.3960120082f, 0.5833039880f),
        new Vector2(0.4201210141f, 0.5897719860f),
        new Vector2(0.0075610001f, 0.5192229748f),
        new Vector2(0.4329490066f, 0.4304820299f),
        new Vector2(0.4586389959f, 0.5209109783f),
        new Vector2(0.4734660089f, 0.4542559981f),
        new Vector2(0.4760879874f, 0.4361699820f),
        new Vector2(0.4684720039f, 0.4449430108f),
        new Vector2(0.4339909852f, 0.4176380038f),
        new Vector2(0.4835180044f, 0.4370160103f),
        new Vector2(0.4824829996f, 0.4221509695f),
        new Vector2(0.4264500141f, 0.6102010012f),
        new Vector2(0.4389989972f, 0.6035050154f),
        new Vector2(0.4500670135f, 0.5995659828f),
        new Vector2(0.2897120118f, 0.6317470074f),
        new Vector2(0.2766700089f, 0.6366270185f),
        new Vector2(0.5178620219f, 0.5280519724f),
        new Vector2(0.7102879882f, 0.6192359924f),
        new Vector2(0.5262269974f, 0.4260900021f),
        new Vector2(0.8950930238f, 0.7458590269f),
        new Vector2(0.6340699792f, 0.5904240012f),
        new Vector2(0.6612420082f, 0.5869749784f),
        new Vector2(0.6888800263f, 0.5905399919f),
        new Vector2(0.7253419757f, 0.6108689904f),
        new Vector2(0.6066300273f, 0.5962949991f),
        new Vector2(0.6547660232f, 0.6559889913f),
        new Vector2(0.6299059987f, 0.6539239883f),
        new Vector2(0.6806780100f, 0.6527349949f),
        new Vector2(0.7020969987f, 0.6464089751f),
        new Vector2(0.7522119880f, 0.5891950130f),
        new Vector2(0.6029180288f, 0.1571370363f),
        new Vector2(0.7199019790f, 0.6244000196f),
        new Vector2(0.8936929703f, 0.6000400186f),
        new Vector2(0.7900819778f, 0.6086459756f),
        new Vector2(0.6439980268f, 0.4655120373f),
        new Vector2(0.5282490253f, 0.3495960236f),
        new Vector2(0.5258499980f, 0.3198089600f),
        new Vector2(0.5602149963f, 0.3427709937f),
        new Vector2(0.5853840113f, 0.3334590197f),
        new Vector2(0.5496259928f, 0.3191390038f),
        new Vector2(0.5712280273f, 0.3173080087f),
        new Vector2(0.6248520017f, 0.2719010115f),
        new Vector2(0.5130500197f, 0.4527180195f),
        new Vector2(0.5150970221f, 0.4727480412f),
        new Vector2(0.7422469854f, 0.6854929924f),
        new Vector2(0.5986310244f, 0.5450209975f),
        new Vector2(0.5703380108f, 0.4514249563f),
        new Vector2(0.5786319971f, 0.4663770199f),
        new Vector2(0.7230870128f, 0.4679459929f),
        new Vector2(0.5164459944f, 0.5003610253f),
        new Vector2(0.6628010273f, 0.7170820236f),
        new Vector2(0.7036240101f, 0.7067289948f),
        new Vector2(0.8307049870f, 0.8061860204f),
        new Vector2(0.5523859859f, 0.6974319816f),
        new Vector2(0.6076099873f, 0.6461120248f),
        new Vector2(0.6454290152f, 0.3032929897f),
        new Vector2(0.9326949716f, 0.2698949575f),
        new Vector2(0.5572609901f, 0.4271739721f),
        new Vector2(0.5429019928f, 0.4152079821f),
        new Vector2(0.6180260181f, 0.3052890301f),
        new Vector2(0.6075909734f, 0.3057969809f),
        new Vector2(0.7229430079f, 0.7280369997f),
        new Vector2(0.5774139762f, 0.4368330240f),
        new Vector2(0.6140829921f, 0.7186130285f),
        new Vector2(0.6169070005f, 0.7441139817f),
        new Vector2(0.6685090065f, 0.8800860047f),
        new Vector2(0.7700920105f, 0.7679790258f),
        new Vector2(0.6355360150f, 0.8107510209f),
        new Vector2(0.7703909874f, 0.7004439831f),
        new Vector2(0.8267220259f, 0.7212449908f),
        new Vector2(0.5271210074f, 0.3338019848f),
        new Vector2(0.5531719923f, 0.3314729929f),
        new Vector2(0.5772380233f, 0.3261100054f),
        new Vector2(0.5546919703f, 0.4199340343f),
        new Vector2(0.6118969917f, 0.3060389757f),
        new Vector2(0.5969610214f, 0.2934600115f),
        new Vector2(0.5963709950f, 0.3060469627f),
        new Vector2(0.5399580002f, 0.4428609610f),
        new Vector2(0.5688419938f, 0.3076339960f),
        new Vector2(0.5478180051f, 0.3076339960f),
        new Vector2(0.5246130228f, 0.3076339960f),
        new Vector2(0.5340899825f, 0.2208589911f),
        new Vector2(0.5276709795f, 0.2637740374f),
        new Vector2(0.5269129872f, 0.2821429968f),
        new Vector2(0.5268779993f, 0.2953740358f),
        new Vector2(0.5269669890f, 0.3047220111f),
        new Vector2(0.5720580220f, 0.3047220111f),
        new Vector2(0.5735210180f, 0.2964600325f),
        new Vector2(0.5768380165f, 0.2881540060f),
        new Vector2(0.5816910267f, 0.2799370289f),
        new Vector2(0.6099449992f, 0.3600900173f),
        new Vector2(0.9860460162f, 0.4399659634f),
        new Vector2(0.5867999792f, 0.3046000004f),
        new Vector2(0.5903720260f, 0.2981770039f),
        new Vector2(0.5319150090f, 0.3984630108f),
        new Vector2(0.5772680044f, 0.4140650034f),
        new Vector2(0.5369150043f, 0.4062139988f),
        new Vector2(0.6275429726f, 0.5266479850f),
        new Vector2(0.6655859947f, 0.5040490031f),
        new Vector2(0.5883539915f, 0.4531379938f),
        new Vector2(0.7578240037f, 0.8523240089f),
        new Vector2(0.7092499733f, 0.7984920144f),
        new Vector2(0.6726840138f, 0.7434189916f),
        new Vector2(0.6004089713f, 0.2509950399f),
        new Vector2(0.5582659841f, 0.7383279800f),
        new Vector2(0.5703039765f, 0.8121290207f),
        new Vector2(0.5881659985f, 0.8909559846f),
        new Vector2(0.7110450268f, 0.6010479927f),
        new Vector2(0.7810699940f, 0.5645949841f),
        new Vector2(0.5872470140f, 0.6010680199f),
        new Vector2(0.7428699732f, 0.6445540190f),
        new Vector2(0.5721560121f, 0.5623480082f),
        new Vector2(0.5518680215f, 0.4634299874f),
        new Vector2(0.8214420080f, 0.5424439907f),
        new Vector2(0.7527019978f, 0.5428180099f),
        new Vector2(0.7137569785f, 0.5323730111f),
        new Vector2(0.6671130061f, 0.5393270254f),
        new Vector2(0.6311010122f, 0.5528460145f),
        new Vector2(0.6008620262f, 0.5675269961f),
        new Vector2(0.5234810114f, 0.5943729877f),
        new Vector2(0.8107479811f, 0.4760739803f),
        new Vector2(0.7710459828f, 0.6510409713f),
        new Vector2(0.5091270208f, 0.4372819662f),
        new Vector2(0.5952929854f, 0.5149760246f),
        new Vector2(0.9805309772f, 0.5984359980f),
        new Vector2(0.5734999776f, 0.5799999833f),
        new Vector2(0.6029949784f, 0.4513120055f),
        new Vector2(0.7335299850f, 0.6230229735f),
        new Vector2(0.5606110096f, 0.4809830189f),
        new Vector2(0.9676859975f, 0.3556430340f),
        new Vector2(0.5809850097f, 0.6128399968f),
        new Vector2(0.5377280116f, 0.4946149588f),
        new Vector2(0.7609660029f, 0.2202470303f),
        new Vector2(0.8017789721f, 0.1680619717f),
        new Vector2(0.8924409747f, 0.4592390060f),
        new Vector2(0.8163509965f, 0.2597399950f),
        new Vector2(0.8655949831f, 0.6663129926f),
        new Vector2(0.6140739918f, 0.1167539954f),
        new Vector2(0.5089529753f, 0.4205620289f),
        new Vector2(0.6179419756f, 0.4916839600f),
        new Vector2(0.8256080151f, 0.6023250222f),
        new Vector2(0.6812149882f, 0.6037650108f),
        new Vector2(0.6566359997f, 0.5994030237f),
        new Vector2(0.6039000154f, 0.2897830009f),
        new Vector2(0.8120859861f, 0.4114609957f),
        new Vector2(0.5680130124f, 0.0554350019f),
        new Vector2(0.6810079813f, 0.1017149687f),
        new Vector2(0.7337520123f, 0.1302989721f),
        new Vector2(0.6338300109f, 0.6011779904f),
        new Vector2(0.6067929864f, 0.6044629812f),
        new Vector2(0.5896599889f, 0.6089379787f),
        new Vector2(0.8050159812f, 0.6578919888f),
        new Vector2(0.6113349795f, 0.6377159953f),
        new Vector2(0.6340379715f, 0.6440290213f),
        new Vector2(0.6566359997f, 0.6446430087f),
        new Vector2(0.6812149882f, 0.6416599751f),
        new Vector2(0.6985849738f, 0.6368439794f),
        new Vector2(0.9418669939f, 0.6809239984f),
        new Vector2(0.6985849738f, 0.6125509739f),
        new Vector2(0.5841770172f, 0.3758929968f),
        new Vector2(0.5543180108f, 0.4339230061f),
        new Vector2(0.5341539979f, 0.3793599606f),
        new Vector2(0.7112179995f, 0.1800249815f),
        new Vector2(0.6646299958f, 0.1471289992f),
        new Vector2(0.5590999722f, 0.0973680019f),
        new Vector2(0.8717060089f, 0.2080590129f),
        new Vector2(0.5912340283f, 0.6261060238f),
        new Vector2(0.5443410277f, 0.5484160185f),
        new Vector2(0.6245629787f, 0.0758079886f),
        new Vector2(0.8857700229f, 0.3849710226f),
        new Vector2(0.5513380170f, 0.3047220111f),
        new Vector2(0.5519800186f, 0.2953679562f),
        new Vector2(0.5528879762f, 0.2841919661f),
        new Vector2(0.5551679730f, 0.2692059875f),
        new Vector2(0.5699440241f, 0.2329649925f),
        new Vector2(0.5932030082f, 0.3143240213f),
        new Vector2(0.5992619991f, 0.3189309835f),
        new Vector2(0.6075999737f, 0.3222969770f),
        new Vector2(0.6319379807f, 0.3364999890f),
        new Vector2(0.7520329952f, 0.3986849785f),
        new Vector2(0.5472260118f, 0.5796049833f),
        new Vector2(0.5635439754f, 0.6401720047f),
        new Vector2(0.5838410258f, 0.6312860250f),
        new Vector2(0.5866140127f, 0.3076339960f),
        new Vector2(0.7719150186f, 0.3164219856f),
        new Vector2(0.5315970182f, 0.6475170255f),
        new Vector2(0.5883709788f, 0.1955590248f),
        new Vector2(0.5207970142f, 0.5574349761f),
        new Vector2(0.5679849982f, 0.5065209866f),
        new Vector2(0.5432829857f, 0.1807450056f),
        new Vector2(0.6553170085f, 0.2544850111f),
        new Vector2(0.6210089922f, 0.4259819984f),
        new Vector2(0.6255599856f, 0.2196879983f),
        new Vector2(0.6801980138f, 0.4292809963f),
        new Vector2(0.6427639723f, 0.3956620097f),
        new Vector2(0.7046629786f, 0.3784700036f),
        new Vector2(0.5520120263f, 0.1374080181f),
        new Vector2(0.5890719891f, 0.4913629889f),
        new Vector2(0.6859449744f, 0.2246429920f),
        new Vector2(0.6457350254f, 0.1873599887f),
        new Vector2(0.6753429770f, 0.2960219979f),
        new Vector2(0.8108580112f, 0.3536950350f),
        new Vector2(0.7201219797f, 0.2853330374f),
        new Vector2(0.8661519885f, 0.3172950149f),
        new Vector2(0.6631870270f, 0.3554030061f),
        new Vector2(0.5700820088f, 0.5336740017f),
        new Vector2(0.5445619822f, 0.4516240358f),
        new Vector2(0.5627589822f, 0.4412150383f),
        new Vector2(0.5319870114f, 0.4698599577f),
        new Vector2(0.5852710009f, 0.6648229957f),
        new Vector2(0.6229529977f, 0.6772210002f),
        new Vector2(0.6558960080f, 0.6798369884f),
        new Vector2(0.6871320009f, 0.6776540279f),
        new Vector2(0.7164819837f, 0.6667990088f),
        new Vector2(0.7587569952f, 0.6172130108f),
        new Vector2(0.8970130086f, 0.5312309861f),
        new Vector2(0.7323920131f, 0.5754529834f),
        new Vector2(0.7021139860f, 0.5668370128f),
        new Vector2(0.6665250063f, 0.5661339760f),
        new Vector2(0.6335049868f, 0.5739120245f),
        new Vector2(0.6038759947f, 0.5834130049f),
        new Vector2(0.5796579719f, 0.5900549889f),
        new Vector2(0.9924399853f, 0.5192229748f),
        new Vector2(0.5671920180f, 0.4305800200f),
        new Vector2(0.5413659811f, 0.5211009979f),
        new Vector2(0.5265640020f, 0.4538819790f),
        new Vector2(0.5239130259f, 0.4361699820f),
        new Vector2(0.5315290093f, 0.4449430108f),
        new Vector2(0.5660359859f, 0.4176709652f),
        new Vector2(0.5163109899f, 0.4369460344f),
        new Vector2(0.5174720287f, 0.4221229553f),
        new Vector2(0.5735949874f, 0.6101930141f),
        new Vector2(0.5606979728f, 0.6046680212f),
        new Vector2(0.5497559905f, 0.6002489924f),
        new Vector2(0.7102879882f, 0.6317470074f),
        new Vector2(0.7233300209f, 0.6366270185f)
    };
}

} // namespace MediaPipe
